/****************************************************************************************************
 * This file contains a function that ensures that the CC2420 crystal oscillator is stable.			*
 *											*
 * EXAMPLE OF USAGE:									*
 *     // Turn the crystal oscillator on and wait for it to become stable					*
 *     DISBALE_GLOBAL_INT();									*
 *     FASTSPI_STROBE(CC2420_SXOSCON); 							*
 *     ENABLE_GLOBAL_INT(); 									*
 *     halRfWaitForCrystalOscillator();								*
 ****************************************************************************************************/
#include "include/include.h"


//----------------------------------------------------------------------------------------------------
//	void rfWaitForCrystalOscillator(void)
//
//	DESCRIPTION:
//		Waits for the crystal oscillator to become stable. The flag is polled via the SPI status byte.
//      
//      Note that this function will lock up if the SXOSCON command strobe has not been given before the
//      function call. Also note that global interrupts will always be enabled when this function 
//      returns.
//----------------------------------------------------------------------------------------------------
void halRfWaitForCrystalOscillator(void) {
    BYTE spiStatusByte;

    // Poll the SPI status byte until the crystal oscillator is stable
    do {
	    DISABLE_GLOBAL_INT();
	    FASTSPI_UPD_STATUS(spiStatusByte);
	    ENABLE_GLOBAL_INT();
    } while (!(spiStatusByte & (BM(CC2420_XOSC16M_STABLE))));

} // halRfWaitForCrystalOscillator
